@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: amd.h,v 1.8.2.6 2002/12/27 22:44:29 ezk Exp $
+ * $Id: amd.h,v 1.8.2.13 2005/03/18 05:09:48 ottavio Exp $
  *
  */
 
@@ -50,6 +50,14 @@
  * MACROS:
  */
 
+/*
+ * Define a default debug mtab path for systems
+ * that support mtab on file.
+ */
+#ifdef MOUNT_TABLE_ON_FILE
+# define DEBUG_MTAB_FILE		"/tmp/mnttab"
+#endif
+
 /* options for amd.conf */
 #define CFM_BROWSABLE_DIRS		0x0001
 #define CFM_MOUNT_TYPE_AUTOFS		0x0002
@@ -62,6 +70,7 @@
 #define CFM_FULLY_QUALIFIED_HOSTS	0x0100
 #define CFM_BROWSABLE_DIRS_FULL		0x0200 /* allow '/' in readdir() */
 #define CFM_UNMOUNT_ON_EXIT		0x0400 /* when amd finishing */
+#define CFM_NFS_INSECURE_PORT		0x0800
 
 /* some systems (SunOS 4.x) neglect to define the mount null message */
 #ifndef MOUNTPROC_NULL
@@ -83,6 +92,9 @@
 
 typedef struct cf_map cf_map_t;
 typedef struct kv kv;
+
+typedef voidp opaque_t;
+
 /*
  * Cache map operations
  */
@@ -116,12 +128,13 @@ struct amu_global_options {
   char *map_type;		/* global map type */
   char *search_path;		/* search path for maps */
   char *mount_type;		/* mount type for map */
+  char *debug_mtab_file;        /* path for the mtab file during debug mode */
   u_int flags;			/* various CFM_* flags */
   int amfs_auto_retrans;	/* NFS retransmit counter */
   int amfs_auto_timeo;		/* NFS retry interval */
   int am_timeo;			/* cache duration */
   int am_timeo_w;		/* dismount interval */
-  int portmap_program;		/* amd RPC program number */
+  u_int portmap_program;	/* amd RPC program number */
 #ifdef HAVE_MAP_HESIOD
   char *hesiod_base;		/* Hesiod rhs */
 #endif /* HAVE_MAP_HESIOD */
@@ -130,6 +143,7 @@ struct amu_global_options {
   char *ldap_hostports;		/* LDAP host ports */
   long ldap_cache_seconds; 	/* LDAP internal cache - keep seconds */
   long ldap_cache_maxmem;	/* LDAP internal cache - max memory (bytes) */
+  long ldap_proto_version;
 #endif /* HAVE_MAP_LDAP */
 #ifdef HAVE_MAP_NIS
   char *nis_domain;		/* YP domain name */
@@ -239,6 +253,7 @@ extern int mount_nfs_fh(am_nfs_handle_t *fhp, char *dir, char *fs_name, char *op
 extern int process_last_regular_map(void);
 extern int set_conf_kv(const char *section, const char *k, const char *v);
 extern int try_mount(voidp mvp);
+extern int unmount_mp(am_node *mp); 
 extern int yyparse (void);
 extern nfsentry *make_entry_chain(am_node *mp, const nfsentry *current_chain, int fully_browsable);
 extern void amfs_auto_cont(int rc, int term, voidp closure);
