@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: map.c,v 1.6.2.7 2002/12/27 22:44:38 ezk Exp $
+ * $Id: map.c,v 1.6.2.10 2005/03/18 05:09:48 ottavio Exp $
  *
  */
 
@@ -786,9 +786,14 @@ umount_exported(void)
 	  mf->mf_flags &= ~MFF_MKMNT;
 	if (gopt.flags & CFM_UNMOUNT_ON_EXIT) {
 	  plog(XLOG_INFO, "on-exit attempt to unmount %s", mf->mf_mount);
-	  unmount_node(mp);
+	  /* 
+	   * use unmount_mp, not unmount_node, so that unmounts be 
+	   * backgrounded as needed. 
+	   */ 
+	  unmount_mp((opaque_t) mp);
+	} else {
+	  am_unmounted(mp); 
 	}
-	am_unmounted(mp);
 
       } else {
 	/*
@@ -932,7 +937,7 @@ free_map_if_success(int rc, int term, voidp closure)
 }
 
 
-static int
+int
 unmount_mp(am_node *mp)
 {
   int was_backgrounded = 0;
