@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: mapc.c,v 1.7.2.6 2002/12/27 22:44:38 ezk Exp $
+ * $Id: mapc.c,v 1.7.2.9 2005/01/03 20:56:12 ezk Exp $
  *
  */
 
@@ -1101,7 +1101,8 @@ make_entry_chain(am_node *mp, const nfsentry *current_chain, int fully_browsable
   static nfsentry chain[MAX_CHAIN];
   static int max_entries = MAX_CHAIN;
   char *key;
-  int num_entries = 0, preflen = 0, i;
+  int num_entries = 0, i;
+  u_int preflen = 0;
   nfsentry *retval = (nfsentry *) NULL;
   mntfs *mf;
   mnt_map *mmp;
