@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: ops_pcfs.c,v 1.3.2.4 2002/12/27 22:44:42 ezk Exp $
+ * $Id: ops_pcfs.c,v 1.3.2.7 2005/01/03 20:56:12 ezk Exp $
  *
  */
 
@@ -134,6 +134,10 @@ mount_pcfs(char *dir, char *fs_name, char *opts)
   pcfs_args.mask = 0777;	/* this may be the msdos file modes */
 #endif /* HAVE_PCFS_ARGS_T_MASK */
 
+#ifdef HAVE_PCFS_ARGS_T_DIRMASK
+  pcfs_args.dirmask = 0777;    /* this may be the msdos dir modes */
+#endif /* HAVE_PCFS_ARGS_T_DIRMASK */
+
 #ifdef HAVE_PCFS_ARGS_T_UID
   pcfs_args.uid = 0;		/* root */
 #endif /* HAVE_PCFS_ARGS_T_UID */
