@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: opts.c,v 1.8.2.6 2002/12/27 22:44:43 ezk Exp $
+ * $Id: opts.c,v 1.8.2.9 2005/01/16 23:56:32 ezk Exp $
  *
  */
 
@@ -869,7 +869,7 @@ normalize_slash(char *p)
 static void
 expand_op(opt_apply *p, int sel_p)
 {
-  static const char expand_error[] = "No space to expand \"%s\"";
+#define EXPAND_ERROR "No space to expand \"%s\""
   char expbuf[MAXPATHLEN + 1];
   char nbuf[NLEN + 1];
   char *ep = expbuf;
@@ -892,7 +892,7 @@ expand_op(opt_apply *p, int sel_p)
 	strncpy(ep, cp, len);
 	ep += len;
       } else {
-	plog(XLOG_ERROR, expand_error, *p->opt);
+	plog(XLOG_ERROR, EXPAND_ERROR, *p->opt);
 	goto out;
       }
     }
@@ -903,7 +903,7 @@ expand_op(opt_apply *p, int sel_p)
       if (BUFSPACE(ep, 1)) {
 	*ep++ = '$';
       } else {
-	plog(XLOG_ERROR, expand_error, *p->opt);
+	plog(XLOG_ERROR, EXPAND_ERROR, *p->opt);
 	goto out;
       }
     } else if (ch == '{') {
@@ -1071,7 +1071,7 @@ expand_op(opt_apply *p, int sel_p)
 	      strcpy(ep, vptr);
 	      ep += vlen;
 	    } else {
-	      plog(XLOG_ERROR, expand_error, *p->opt);
+	      plog(XLOG_ERROR, EXPAND_ERROR, *p->opt);
 	      goto out;
 	    }
 	  }
@@ -1100,7 +1100,7 @@ expand_op(opt_apply *p, int sel_p)
 	    strcpy(ep, env);
 	    ep += vlen;
 	  } else {
-	    plog(XLOG_ERROR, expand_error, *p->opt);
+	    plog(XLOG_ERROR, EXPAND_ERROR, *p->opt);
 	    goto out;
 	  }
 #ifdef DEBUG
@@ -1133,7 +1133,7 @@ out:
       strcpy(ep, cp);
       /* ep += strlen(ep); */
     } else {
-      plog(XLOG_ERROR, expand_error, *p->opt);
+      plog(XLOG_ERROR, EXPAND_ERROR, *p->opt);
     }
 
     /*
