@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: pawd.c,v 1.6.2.3 2002/12/27 22:44:46 ezk Exp $
+ * $Id: pawd.c,v 1.6.2.6 2005/01/03 20:56:12 ezk Exp $
  *
  */
 
@@ -91,7 +91,7 @@ find_mt(amq_mount_tree *mt, char *dir)
 static int
 find_mlp(amq_mount_tree_list *mlp, char *dir)
 {
-  int i;
+  u_int i;
 
   for (i = 0; i < mlp->amq_mount_tree_list_len; i++) {
     if (find_mt(mlp->amq_mount_tree_list_val[i], dir))
