@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: checkmount_aix.c,v 1.4.2.3 2002/12/27 22:44:46 ezk Exp $
+ * $Id: checkmount_aix.c,v 1.4.2.6 2005/03/12 20:08:30 ottavio Exp $
  *
  */
 
@@ -49,8 +49,10 @@
 
 /* external definitions */
 extern int is_same_host(char *name1, char *name2, struct in_addr addr2);
+#if 0
+#error no longer needed on AIX 5.3
 extern int mntctl(int Command, int Size, char *Buffer);
-
+#endif
 
 int
 fixmount_check_mount(char *host, struct in_addr hostaddr, char *path)
