@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: mtab_aix.c,v 1.5.2.3 2002/12/27 22:44:50 ezk Exp $
+ * $Id: mtab_aix.c,v 1.5.2.8 2005/03/15 03:27:29 ezk Exp $
  *
  */
 
@@ -54,8 +54,14 @@
 #include <am_defs.h>
 #include <amu.h>
 
-/* missing external definitions from AIX's headers */
+/*
+ * These were missing external definitions from old AIX's headers.  They
+ * appear to be available in <sys/vmount.h> on AIX 5.3, and possibly
+ * earlier. Hence I commented this out.
+ */
+#if 0
 extern int mntctl(int cmd, int size, voidp buf);
+#endif
 
 
 static mntent_t *
@@ -116,23 +122,34 @@ mntlist *
 read_mtab(char *fs, const char *mnttabname)
 {
   mntlist **mpp, *mhp;
-
   int i;
   char *mntinfo = 0, *cp;
   struct vmount *vp;
   int ret;
+  int maxtry = 10;		/* maximum number of times to try mntctl */
 
   /*
-   * First figure out size of mount table
-   * and allocate space for a copy...
-   * Then get mount table for real.
+   * Figure out size of mount table and allocate space for a copy.  Then get
+   * mount table for real.  We repeat this loop at most 10 times to minimze
+   * the chance of a race condition (something gets un/mounted in between
+   * calls to mntctl()
    */
-  ret = mntctl(MCTL_QUERY, sizeof(i), &i);
-  if (ret == 0) {
+  i = sizeof(int);
+  do {
+    if (mntinfo)
+      XFREE(mntinfo);
     mntinfo = xmalloc(i);
     ret = mntctl(MCTL_QUERY, i, mntinfo);
-  }
-  if (ret <= 0) {
+    if (ret == 0)
+      i = *(int*) mntinfo;
+    if (--maxtry <= 0) {
+      plog(XLOG_ERROR, "mntctl: could not get a stable result");
+      ret = -1;
+      errno = EINVAL;
+      break;
+    }
+  } while (ret == 0);
+  if (ret < 0) {
     plog(XLOG_ERROR, "mntctl: %m");
     goto out;
   }
