@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: mtab_mach3.c,v 1.4.2.5 2002/12/27 22:44:51 ezk Exp $
+ * $Id: mtab_mach3.c,v 1.4.2.8 2005/03/04 18:42:04 ezk Exp $
  *
  */
 
@@ -136,7 +136,14 @@ again:
       sleep(1);
       goto again;
     }
-    return 0;
+    /*
+     * If 'mnttabname' file does not exist give setmntent() a
+     * chance to create it (depending on the mode).
+     * Otherwise, bail out.
+     */
+    else if (errno != ENOENT) {
+      return 0;
+    }
   }
 eacces:
   mfp = setmntent(mnttabname, mode);
