@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_freebsd3.h,v 1.5.2.4 2002/12/27 22:44:54 ezk Exp $
+ * $Id: nfs_prot_freebsd3.h,v 1.5.2.8 2005/01/03 20:56:13 ezk Exp $
  *
  */
 
@@ -58,6 +58,11 @@
 # include <ufs/ufs/ufsmount.h>
 #endif	/* HAVE_UFS_UFS_UFSMOUNT_H */
 
+/* nfsclient/nfsargs.h was introduced in FreeBSD 5.0, and is needed */
+#ifdef	HAVE_NFSCLIENT_NFSARGS_H
+# include <nfsclient/nfsargs.h>
+#endif	/* HAVE_NFSCLIENT_NFSARGS_H */
+
 /*
  * MACROS:
  */
@@ -83,6 +88,7 @@
 #define na_nlink	nlink
 #define na_size		size
 #define na_type		type
+#define na_uid		uid
 #define ne_cookie	cookie
 #define ne_fileid	fileid
 #define ne_name		name
