@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: nfs_prot_openbsd.h,v 1.3.2.4 2002/12/27 22:44:57 ezk Exp $
+ * $Id: nfs_prot_openbsd.h,v 1.3.2.7 2005/01/16 23:56:32 ezk Exp $
  *
  */
 
@@ -59,6 +58,56 @@
 # include <nfs/nfs.h>
 #endif /* HAVE_NFS_NFS_H */
 
+#ifdef HAVE_SYS_MOUNT_H
+# include <net/radix.h>
+# include <sys/socket.h>         /* XXX for AF_MAX */
+/*
+ * Get some definitions from sys/mount which would have only gotten included
+ * if _KERNEL was defined, but we don't want to define it in am_defs.h
+ * globally.
+ */
+/* Network address lookup element */
+struct netcred {
+  struct  radix_node netc_rnodes[2];
+  int     netc_exflags;
+  struct  ucred netc_anon;
+};
+
+/* Network export information */
+struct netexport {
+  struct  netcred ne_defexported;               /* Default export */
+  struct  radix_node_head *ne_rtable[AF_MAX+1]; /* Individual exports */
+};
+#endif /* HAVE_SYS_MOUNT_H */
+
+#ifdef	HAVE_UFS_UFS_UFSMOUNT_H
+#if 1
+# ifdef HAVE_UFS_UFS_EXTATTR_H
+/*
+ * Need to define _KERNEL to include protected definition of struct
+ * ufs_extattr_per_mount, which is used in struct ufsmount in
+ * <ufs/ufs/ufsmount.h>, but is NOT protected by _KERNEL there.
+ */
+#  define _KERNEL
+#  include <ufs/ufs/extattr.h>
+#  undef _KERNEL
+# endif /* HAVE_UFS_UFS_EXTATTR_H */
+#endif /* 1 */
+# ifndef MAXQUOTAS
+#  define MAXQUOTAS     2
+# endif /* not MAXQUOTAS */
+#if 0
+#error No longer needed in openbsd3.6
+/*
+ * XXX: fake struct nextexport: trying to include proper headers here is too
+ * difficult: those headers drag many other headers, etc.
+ */
+struct netexport { int this_is_SO_wrong; };
+#endif /* 0 */
+//struct netexport;
+# include <ufs/ufs/ufsmount.h>
+#endif	/* HAVE_UFS_UFS_UFSMOUNT_H */
+
 
 /*
  * MACROS:
@@ -85,6 +134,8 @@
 #define na_nlink	nlink
 #define na_size		size
 #define na_type		type
+#define na_uid		uid
+#define na_gid		gid
 #define ne_cookie	cookie
 #define ne_fileid	fileid
 #define ne_name		name
@@ -158,16 +209,28 @@ typedef writeargs nfswriteargs;
 
 # define MOUNT_NFS3 MOUNT_NFS
 # define MNTOPT_NFS3 "nfs"
-
-#define FHSIZE3 64		/* size in bytes of a file handle (v3) */
+# define MOUNTVERS3 ((unsigned long)(3))
 #define	NFS3_FHSIZE 64
-#define	MOUNTVERS3 ((unsigned long)(3))
-#define	NFS_V3 ((unsigned long)(3))
+#define FHSIZE3 64		/* size in bytes of a file handle (v3) */
 
-typedef struct {
+struct nfs_fh3 {
+  u_int fh3_length;
+  union nfs_fh3_u {
+    struct nfs_fh3_i {
+      fhandle_t fh3_i;
+    } nfs_fh3_i;
+    char data[NFS3_FHSIZE];
+  } fh3_u;
+};
+typedef struct nfs_fh3 fhandle3;
+#define fhandle3_len fh3_length
+#define fhandle3_val fh3_u.data
+#if 0
+typedef struct fhandle3 {
   u_int fhandle3_len;
   char *fhandle3_val;
 } fhandle3;
+#endif
 
 enum mountstat3 {
   MNT3_OK = 0,
@@ -200,17 +263,6 @@ struct mountres3 {
 };
 typedef struct mountres3 mountres3;
 
-struct nfs_fh3 {
-  u_int fh3_length;
-  union nfs_fh3_u {
-    struct nfs_fh3_i {
-      fhandle_t fh3_i;
-    } nfs_fh3_i;
-    char data[NFS3_FHSIZE];
-  } fh3_u;
-};
-typedef struct nfs_fh3 nfs_fh3;
-
 #endif /* NFSMNT_NFSV3 */
 
 #endif /* not _AMU_NFS_PROT_H */
