@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: fsi_analyze.c,v 1.3.2.3 2002/12/27 22:45:04 ezk Exp $
+ * $Id: fsi_analyze.c,v 1.3.2.6 2005/01/03 20:56:14 ezk Exp $
  *
  */
 
@@ -130,7 +130,7 @@ compute_hostpath(char *hn)
     }
   } while (d);
 
-  log("hostpath of '%s' is '%s'", hn, path);
+  fsi_log("hostpath of '%s' is '%s'", hn, path);
 
   strcpy(p, path);
   return p;
@@ -145,7 +145,7 @@ find_volname(char *nn)
   char *q;
 
   do {
-    log("Searching for volname %s", p);
+    fsi_log("Searching for volname %s", p);
     de = dict_locate(dict_of_volnames, p);
     q = strrchr(p, '/');
     if (q)
@@ -161,7 +161,7 @@ static void
 show_required(ioloc *l, int mask, char *info, char *hostname, char *strings[])
 {
   int i;
-  log("mask left for %s:%s is %#x", hostname, info, mask);
+  fsi_log("mask left for %s:%s is %#x", hostname, info, mask);
 
   for (i = 0; strings[i]; i++)
     if (ISSET(mask, i))
@@ -218,7 +218,7 @@ analyze_dkmount_tree(qelem *q, fsi_mount *parent, disk_fs *dk)
   int errors = 0;
 
   ITER(mp, fsi_mount, q) {
-    log("Mount %s:", mp->m_name);
+    fsi_log("Mount %s:", mp->m_name);
     if (parent) {
       char n[MAXPATHLEN];
       sprintf(n, "%s/%s", parent->m_name, mp->m_name);
@@ -226,7 +226,7 @@ analyze_dkmount_tree(qelem *q, fsi_mount *parent, disk_fs *dk)
 	lerror(mp->m_ioloc, "sub-directory %s of %s starts with '/'", mp->m_name, parent->m_name);
       else if (STREQ(mp->m_name, "default"))
 	lwarning(mp->m_ioloc, "sub-directory of %s is named \"default\"", parent->m_name);
-      log("Changing name %s to %s", mp->m_name, n);
+      fsi_log("Changing name %s to %s", mp->m_name, n);
       XFREE(mp->m_name);
       mp->m_name = strdup(n);
     }
@@ -287,7 +287,7 @@ analyze_dkmounts(disk_fs *dk, qelem *q)
       compute_automount_point(nbuf, dk->d_host, mp2->m_volname);
       XFREE(mp2->m_name);
       mp2->m_name = strdup(nbuf);
-      log("%s:%s has default mount on %s", dk->d_host->h_hostname, dk->d_dev, mp2->m_name);
+      fsi_log("%s:%s has default mount on %s", dk->d_host->h_hostname, dk->d_dev, mp2->m_name);
     } else {
       lerror(dk->d_ioloc, "no volname given for %s:%s", dk->d_host->h_hostname, dk->d_dev);
       errors++;
@@ -422,24 +422,24 @@ fixup_required_mount_info(fsmount *fp, dict_ent *de)
 	abort();
       fp->f_ref = mp;
       set_fsmount(fp, FM_FROM, mp->m_dk->d_host->h_hostname);
-      log("set: %s comes from %s", fp->f_volname, fp->f_from);
+      fsi_log("set: %s comes from %s", fp->f_volname, fp->f_from);
     }
   }
 
   if (!ISSET(fp->f_mask, FM_FSTYPE)) {
     set_fsmount(fp, FM_FSTYPE, strdup("nfs"));
-    log("set: fstype is %s", fp->f_fstype);
+    fsi_log("set: fstype is %s", fp->f_fstype);
   }
 
   if (!ISSET(fp->f_mask, FM_OPTS)) {
     set_fsmount(fp, FM_OPTS, strdup("rw,nosuid,grpid,defaults"));
-    log("set: opts are %s", fp->f_opts);
+    fsi_log("set: opts are %s", fp->f_opts);
   }
 
   if (!ISSET(fp->f_mask, FM_LOCALNAME)) {
     if (fp->f_ref) {
       set_fsmount(fp, FM_LOCALNAME, strdup(fp->f_volname));
-      log("set: localname is %s", fp->f_localname);
+      fsi_log("set: localname is %s", fp->f_localname);
     } else {
       lerror(fp->f_ioloc, "cannot determine localname since volname %s is not uniquely defined", fp->f_volname);
     }
@@ -461,7 +461,7 @@ analyze_drives(host *hp)
 
   ITER(dp, disk_fs, q) {
     int req;
-    log("Disk %s:", dp->d_dev);
+    fsi_log("Disk %s:", dp->d_dev);
     dp->d_host = hp;
     fixup_required_disk_info(dp);
     req = ~dp->d_mask & DF_REQUIRED;
@@ -498,7 +498,7 @@ analyze_mounts(host *hp)
       do {
 	p = 0;
 	de = find_volname(nn);
-	log("Mount: %s (trying %s)", fp->f_volname, nn);
+	fsi_log("Mount: %s (trying %s)", fp->f_volname, nn);
 
 	if (de) {
 	  found = 1;
@@ -577,7 +577,7 @@ analyze_hosts(qelem *q)
    * Check all drives
    */
   ITER(hp, host, q) {
-    log("disks on host %s", hp->h_hostname);
+    fsi_log("disks on host %s", hp->h_hostname);
     show_new("ana-host");
     hp->h_hostpath = compute_hostpath(hp->h_hostname);
 
@@ -592,7 +592,7 @@ analyze_hosts(qelem *q)
    * Check static mounts
    */
   ITER(hp, host, q) {
-    log("mounts on host %s", hp->h_hostname);
+    fsi_log("mounts on host %s", hp->h_hostname);
     show_new("ana-mount");
     if (hp->h_mount)
       analyze_mounts(hp);
@@ -634,21 +634,21 @@ analyze_automount_tree(qelem *q, char *pref, int lvl)
     sprintf(nname, "%s/%s", pref, ap->a_name);
     XFREE(ap->a_name);
     ap->a_name = strdup(nname[1] == '/' ? nname + 1 : nname);
-    log("automount point %s:", ap->a_name);
+    fsi_log("automount point %s:", ap->a_name);
     show_new("ana-automount");
 
     if (ap->a_mount) {
       analyze_automount_tree(ap->a_mount, ap->a_name, lvl + 1);
     } else if (ap->a_hardwiredfs) {
-      log("\thardwired from %s to %s", ap->a_volname, ap->a_hardwiredfs);
+      fsi_log("\thardwired from %s to %s", ap->a_volname, ap->a_hardwiredfs);
     } else if (ap->a_volname) {
-      log("\tautomount from %s", ap->a_volname);
+      fsi_log("\tautomount from %s", ap->a_volname);
       analyze_automount(ap);
     } else if (ap->a_symlink) {
-      log("\tsymlink to %s", ap->a_symlink);
+      fsi_log("\tsymlink to %s", ap->a_symlink);
     } else {
       ap->a_volname = strdup(ap->a_name);
-      log("\timplicit automount from %s", ap->a_volname);
+      fsi_log("\timplicit automount from %s", ap->a_volname);
       analyze_automount(ap);
     }
   }
