@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -36,9 +36,8 @@
  * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
  * SUCH DAMAGE.
  *
- *      %W% (Berkeley) %G%
  *
- * $Id: fsinfo.c,v 1.5.2.4 2002/12/27 22:45:06 ezk Exp $
+ * $Id: fsinfo.c,v 1.5.2.8 2005/01/03 20:56:14 ezk Exp $
  *
  */
 
@@ -168,7 +167,9 @@ fsi_get_args(int c, char *v[])
 
   if (c != optind) {
     g_argv = v + optind - 1;
+#ifdef yywrap
     if (yywrap())
+#endif /* yywrap */
       fatal("Cannot read any input files");
   } else {
     usage++;
@@ -184,9 +185,9 @@ Usage: %s [-v] [-a autodir] [-h hostname] [-b bootparams] [-d dumpsets]\n\
   }
 
   if (g_argv[0])
-    log("g_argv[0] = %s", g_argv[0]);
+    fsi_log("g_argv[0] = %s", g_argv[0]);
   else
-    log("g_argv[0] = (nil)");
+    fsi_log("g_argv[0] = (nil)");
 }
 
 
