@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: wr_atab.c,v 1.3.2.3 2002/12/27 22:45:07 ezk Exp $
+ * $Id: wr_atab.c,v 1.3.2.6 2005/01/03 20:56:14 ezk Exp $
  *
  */
 
@@ -54,7 +54,7 @@
  * Write a sequence of automount mount map entries
  */
 static int
-write_amount_info(FILE *af, automount *ap,  int sk)
+write_amount_info(FILE *af, automount *ap, u_int sk)
 {
   int errors = 0;
 
