@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: hlfsd.h,v 1.4.2.6 2002/12/27 22:45:08 ezk Exp $
+ * $Id: hlfsd.h,v 1.4.2.9 2005/01/03 20:56:14 ezk Exp $
  *
  * HLFSD was written at Columbia University Computer Science Department, by
  * Erez Zadok <ezk@cs.columbia.edu> and Alexander Dupuy <dupuy@cs.columbia.edu>
@@ -144,14 +144,14 @@ extern char *passwdfile;
 extern char *slinkname;
 extern char mboxfile[];
 extern gid_t hlfs_gid;
-extern int cache_interval;
+extern u_int cache_interval;
 extern int noverify;
 extern int serverpid;
 extern int untab_index(char *username);
 extern am_nfs_fh *root_fhp;
 extern am_nfs_fh root;
 extern nfstime startup;
-extern uid2home_t *plt_search(int);
+extern uid2home_t *plt_search(u_int);
 extern username2uid_t *untab;	/* user name table */
 extern void fatal(char *);
 extern void plt_init(void);
