@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1989 Jan-Simon Pendry
  * Copyright (c) 1989 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1989 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: homedir.c,v 1.5.2.10 2002/12/27 22:45:08 ezk Exp $
+ * $Id: homedir.c,v 1.5.2.13 2005/01/03 20:56:14 ezk Exp $
  *
  * HLFSD was written at Columbia University Computer Science Department, by
  * Erez Zadok <ezk@cs.columbia.edu> and Alexander Dupuy <dupuy@cs.columbia.edu>
@@ -66,7 +66,7 @@ static struct passwd passwd_ent;
 static uid2home_t *lastchild;
 static uid2home_t *pwtab;
 static void delay(uid2home_t *, int);
-static void table_add(int, const char *, const char *);
+static void table_add(u_int, const char *, const char *);
 static char mboxfile[MAXPATHLEN];
 static char *root_home;		/* root's home directory */
 
@@ -690,7 +690,7 @@ plt_reset(void)
  * n: user ID name
  */
 static void
-table_add(int u, const char *h, const char *n)
+table_add(u_int u, const char *h, const char *n)
 {
   int i;
 
@@ -757,7 +757,7 @@ table_add(int u, const char *h, const char *n)
  * return entry in lookup table
  */
 uid2home_t *
-plt_search(int u)
+plt_search(u_int u)
 {
   int max, min, mid;
 
