@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: am_defs.h,v 1.15.2.13 2002/12/27 22:45:09 ezk Exp $
+ * $Id: am_defs.h,v 1.15.2.22 2005/03/15 03:27:30 ezk Exp $
  *
  */
 
@@ -69,6 +69,26 @@
 char *strchr(), *strrchr(), *strdup();
 #endif /* not STDC_HEADERS */
 
+/* AIX requires this to be the first thing in the file. */
+#ifndef __GNUC__
+# if HAVE_ALLOCA_H
+#  include <alloca.h>
+# else /* not HAVE_ALLOCA_H */
+#  ifdef _AIX
+/*
+ * This pragma directive is indented so that pre-ANSI C compilers will
+ * ignore it, rather than choke on it.
+ */
+ #pragma alloca
+#  else /* not _AIX */
+#   ifndef alloca
+/* predefined by HP cc +Olibcalls */
+voidp alloca();
+#   endif /* not alloca */
+#  endif /* not _AIX */
+# endif /* not HAVE_ALLOCA_H */
+#endif /* not __GNUC__ */
+
 /*
  * Handle gcc __attribute__ if available.
  */
@@ -105,6 +125,15 @@ char *strchr(), *strrchr(), *strdup();
  */
 #if TIME_WITH_SYS_TIME
 # include <sys/time.h>
+# ifdef _ALL_SOURCE
+/*
+ * AIX 5.2 needs struct sigevent from signal.h to be defined, but I
+ * don't want to move the inclusion of signal.h this early into this
+ * file.  Luckily, amd doesn't need the size of this structure in any
+ * other structure that it uses.  So we sidestep it for now.
+ */
+struct sigevent;
+# endif /* _ALL_SOURCE */
 # include <time.h>
 #else /* not TIME_WITH_SYS_TIME */
 # if HAVE_SYS_TIME_H
@@ -275,10 +304,13 @@ typedef bool_t (*xdrproc_t) __P ((XDR *, __ptr_t, ...));
 
 /*
  * Actions to take if <malloc.h> exists.
+ * Don't include malloc.h if stdlib.h exists, because modern
+ * systems complain if you use malloc.h instead of stdlib.h.
+ * XXX: let's hope there are no systems out there that need both.
  */
-#ifdef HAVE_MALLOC_H
+#if defined(HAVE_MALLOC_H) && !defined(HAVE_STDLIB_H)
 # include <malloc.h>
-#endif /* HAVE_MALLOC_H */
+#endif /* defined(HAVE_MALLOC_H) && !defined(HAVE_STDLIB_H) */
 
 /*
  * Actions to take if <mntent.h> exists.
@@ -325,21 +357,13 @@ extern int errno;
  * Should be included before <rpcsvc/yp_prot.h> because on some systems
  * like Linux, it also defines "struct datum".
  */
-#ifdef HAVE_NDBM_H
-# include <ndbm.h>
+#ifdef HAVE_MAP_NDBM
+# include NEW_DBM_H
 # ifndef DATUM
 /* ensure that struct datum is not included again from <rpcsvc/yp_prot.h> */
 #  define DATUM
 # endif /* not DATUM */
-#else /* not HAVE_NDBM_H */
-# ifdef HAVE_DB1_NDBM_H
-#  include <db1/ndbm.h>
-#  ifndef DATUM
-/* ensure that struct datum is not included again from <rpcsvc/yp_prot.h> */
-#   define DATUM
-#  endif /* not DATUM */
-# endif /* HAVE_DB1_NDBM_H */
-#endif /* HAVE_NDBM_H */
+#endif /* HAVE_MAP_NDBM */
 
 /*
  * Actions to take if <net/errno.h> exists.
@@ -348,6 +372,13 @@ extern int errno;
 # include <net/errno.h>
 #endif /* HAVE_NET_ERRNO_H */
 
+/*
+ * Actions to take if <net/if.h> exists.
+ */
+#ifdef HAVE_NET_IF_H
+# include <net/if.h>
+#endif /* HAVE_NET_IF_H */
+
 /*
  * Actions to take if <net/route.h> exists.
  */
@@ -381,13 +412,6 @@ extern int errno;
 # endif /* MFREE */
 #endif /* HAVE_SYS_MBUF_H */
 
-/*
- * Actions to take if <net/if.h> exists.
- */
-#ifdef HAVE_NET_IF_H
-# include <net/if.h>
-#endif /* HAVE_NET_IF_H */
-
 /*
  * Actions to take if <netdb.h> exists.
  */
@@ -721,6 +745,14 @@ struct sockaddr_dl;
  * Actions to take if <resolv.h> exists.
  */
 #ifdef HAVE_RESOLV_H
+/*
+ * On AIX 5.2, both <resolv.h> and <arpa/nameser_compat.h> define MAXDNAME,
+ * if compiling with gcc -D_USE_IRS (so that we get extern definitions for
+ * hstrerror() and others).
+ */
+# if defined(_AIX) && defined(MAXDNAME) && defined(_USE_IRS)
+#  undef MAXDNAME
+# endif /* defined(_AIX) && defined(MAXDNAME) && defined(_USE_IRS) */
 # include <resolv.h>
 #endif /* HAVE_RESOLV_H */
 
@@ -752,6 +784,13 @@ struct sockaddr_dl;
 # include <msdosfs/msdosfsmount.h>
 #endif /* HAVE_MSDOSFS_MSDOSFSMOUNT_H */
 
+/*
+ * Actions to take if <fs/msdosfs/msdosfsmount.h> exists.
+ */
+#ifdef HAVE_FS_MSDOSFS_MSDOSFSMOUNT_H
+# include <fs/msdosfs/msdosfsmount.h>
+#endif /* HAVE_FS_MSDOSFS_MSDOSFSMOUNT_H */
+
 /*
  * Actions to take if <sys/fs/tmp.h> exists.
  */
@@ -900,6 +939,18 @@ struct sockaddr_dl;
  * Actions to take if <rpcsvc/nis.h> exists.
  */
 #ifdef HAVE_RPCSVC_NIS_H
+/*
+ * Solaris 10 (build 72) defines GROUP_OBJ in <sys/acl.h>, which is included
+ * in many other header files.  <rpcsvc/nis.h> uses GROUP_OBJ inside enum
+ * zotypes.  So if you're unlucky enough to include both headers, you get a
+ * compile error because the two symbols conflict.
+ *
+ * Temp hack: undefine acl.h's GROUP_OBJ because it's not needed for
+ * am-utils.
+ */
+# ifdef GROUP_OBJ
+#  undef GROUP_OBJ
+# endif /* GROUP_OBJ */
 # include <rpcsvc/nis.h>
 #endif /* HAVE_RPCSVC_NIS_H */
 
