@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1997-2003 Erez Zadok
+ * Copyright (c) 1997-2005 Erez Zadok
  * Copyright (c) 1990 Jan-Simon Pendry
  * Copyright (c) 1990 Imperial College of Science, Technology & Medicine
  * Copyright (c) 1990 The Regents of the University of California.
@@ -38,7 +38,7 @@
  *
  *      %W% (Berkeley) %G%
  *
- * $Id: am_utils.h,v 1.11.2.12 2002/12/27 22:45:10 ezk Exp $
+ * $Id: am_utils.h,v 1.11.2.16 2005/03/04 18:42:05 ezk Exp $
  *
  */
 
@@ -347,7 +347,7 @@ struct mntfs {
 struct am_fh {
   int fhh_pid;			/* process id */
   int fhh_id;			/* map id */
-  int fhh_gen;			/* generation number */
+  u_int fhh_gen;		/* generation number */
 };
 
 /*
@@ -372,7 +372,7 @@ typedef int (*vfmount_fs) (mntfs *);
 typedef int (*vumount_fs) (am_node *);
 typedef int (*vfumount_fs) (mntfs *);
 typedef am_node *(*vlookuppn) (am_node *, char *, int *, int);
-typedef int (*vreaddir) (am_node *, nfscookie, nfsdirlist *, nfsentry *, int);
+typedef int (*vreaddir) (am_node *, nfscookie, nfsdirlist *, nfsentry *, u_int);
 typedef am_node *(*vreadlink) (am_node *, int *);
 typedef void (*vmounted) (mntfs *);
 typedef void (*vumounted) (am_node *);
@@ -792,7 +792,7 @@ extern am_node *amfs_auto_lookuppn(am_node *mp, char *fname, int *error_return,
 extern am_node *next_nonerror_node(am_node *xp);
 extern char *amfs_auto_match(am_opts *fo);
 extern fserver *find_amfs_auto_srvr(mntfs *);
-extern int amfs_auto_readdir(am_node *mp, nfscookie cookie, nfsdirlist *dp, nfsentry *ep, int count);
+extern int amfs_auto_readdir(am_node *mp, nfscookie cookie, nfsdirlist *dp, nfsentry *ep, u_int count);
 extern int amfs_auto_umount(am_node *mp);
 extern int amfs_auto_fmount(am_node *mp);
 extern int amfs_auto_fumount(am_node *mp);
@@ -821,7 +821,7 @@ extern am_ops amfs_direct_ops;	/* Direct Automount file system (this too) */
 #ifdef HAVE_AMU_FS_ERROR
 extern am_ops amfs_error_ops;	/* Error file system */
 extern am_node *amfs_error_lookuppn(am_node *mp, char *fname, int *error_return, int op);
-extern int amfs_error_readdir(am_node *mp, nfscookie cookie, nfsdirlist *dp, nfsentry *ep, int count);
+extern int amfs_error_readdir(am_node *mp, nfscookie cookie, nfsdirlist *dp, nfsentry *ep, u_int count);
 #endif /* HAVE_AMU_FS_ERROR */
 
 /*
@@ -925,11 +925,6 @@ extern am_ops amfs_union_ops;	/* Union FS */
 # define	dlog		amuDebug(D_FULL) dplog
 # define	amuDebugNo(x)	if (!(debug_flags & (x)))
 
-/* debugging mount-table file to use */
-# ifndef DEBUG_MNTTAB
-#  define	DEBUG_MNTTAB	"./mnttab"
-# endif /* not DEBUG_MNTTAB */
-
 # ifdef DEBUG_MEM
 /*
  * If debugging memory, then call a special freeing function that logs
